@@ -3,13 +3,15 @@
 
 #include <stan/math/prim/meta.hpp>
 #include <stan/math/prim/fun/Eigen.hpp>
+#include <stan/math/prim/functor/for_each.hpp>
 #include <vector>
 
 namespace stan {
 namespace math {
 // prints used in generator for print() statements in modeling language
 
-template <typename T, require_not_container_t<T>* = nullptr>
+template <typename T, require_not_container_t<T>* = nullptr,
+          require_not_tuple_t<T>* = nullptr>
 void stan_print(std::ostream* o, const T& x) {
   *o << x;
 }
@@ -50,8 +52,8 @@ void stan_print(std::ostream* o, const EigMat& x) {
   *o << ']';
 }
 
-template <typename T>
-void stan_print(std::ostream* o, const std::vector<T>& x) {
+template <typename T, require_std_vector_t<T>* = nullptr>
+void stan_print(std::ostream* o, const T& x) {
   *o << '[';
   for (size_t i = 0; i < x.size(); ++i) {
     if (i > 0) {
@@ -62,6 +64,23 @@ void stan_print(std::ostream* o, const std::vector<T>& x) {
   *o << ']';
 }
 
+template <typename T, require_tuple_t<T>* = nullptr>
+void stan_print(std::ostream* o, const T& x) {
+  *o << '(';
+  constexpr auto tuple_size = std::tuple_size<std::decay_t<T>>::value;
+  size_t i = 0;
+  stan::math::for_each(
+      [&i, o](auto&& elt) {
+        if (i > 0) {
+          *o << ',';
+        }
+        stan_print(o, elt);
+        i++;
+      },
+      x);
+  *o << ')';
+}
+
 }  // namespace math
 }  // namespace stan
 #endif
